@@ -20,6 +20,23 @@ along with pyroaddon.  If not, see <https://www.gnu.org/licenses/>.
 
 import pyrogram 
 
-def dice(ctx, message):
-    return hasattr(message, 'dice') and message.dice
+@pyrogram.filters.create
+def dice(_, __, message: pyrogram.types.Message):
+    if message.dice:
+        return True
+    return False
 pyrogram.filters.dice = dice
+
+@pyrogram.filters.create
+async def ttl_message(_, __, m: pyrogram.types.Message):
+    if (m.photo and m.photo.ttl_seconds) or (m.video and m.video.ttl_seconds):
+        return True
+    return False
+pyrogram.filters.ttl_message = ttl_message
+
+@pyrogram.filters.create
+async def video_sticker(_, __, m: pyrogram.types.Message):
+    if await pyrogram.filters.sticker(__, m):
+        return m.sticker.is_video
+    return False
+pyrogram.filters.video_sticker = video_sticker
